# hckr -  cli hack for developers
[![PyPI - Version](https://img.shields.io/pypi/v/hckr.svg)](https://pypi.org/project/hckr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hckr.svg)](https://pypi.org/project/hckr)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=hckr-cli_hckr&metric=coverage)](https://sonarcloud.io/summary/new_code?id=hckr-cli_hckr)
[![Dependabot](https://github.com/hckr-cli/hckr/actions/workflows/dependabot/dependabot-updates/badge.svg)](https://github.com/hckr-cli/hckr/actions/workflows/dependabot/dependabot-updates)
[![Build](https://github.com/hckr-cli/hckr/actions/workflows/build.yml/badge.svg)](https://github.com/hckr-cli/hckr/actions/workflows/build.yml)
[![Documentation Status](https://readthedocs.org/projects/hckr/badge/?version=latest)](https://hckr.readthedocs.io/en/latest/?badge=latest)
 
[![SonarCloud](https://sonarcloud.io/images/project_badges/sonarcloud-black.svg)](https://sonarcloud.io/summary/new_code?id=hckr-cli_hckr)
[![Quality gate](https://sonarcloud.io/api/project_badges/quality_gate?project=hckr-cli_hckr)](https://sonarcloud.io/summary/new_code?id=hckr-cli_hckr)

[//]: # ([![GitHub commit activity]&#40;https://img.shields.io/github/commit-activity/m/hckr-cli/hckr&#41;]&#40;https://github.com/hckr-cli/hckr/graphs/commit-activity&#41;)

## Introduction

**hckr** is a command line utililty for developers.
It is focused on facilitating the development of applications by helping devs to do required tasks through utilities provided to enhance efficiency.

## Supporting the project ⭐

If you feel awesome and want to support us in a small way, please consider starring and sharing the repo! This helps us get known and grow the community. 🙏

<img src="https://raw.githubusercontent.com/lusaxweb/vuesax/master/public/github-vuesax-star.gif" alt="vuesax-star" />


## Table of Contents

- [Installation](#installation)
- [License](#license)
- [Contributing](#contributing)
- [Sponsors](#sponsors)

## Installation
* using HomeBrew
```console
brew tap hckr-cli/tap
brew install hckr
```
* using pip
```console
pip install hckr
```
## License

`hckr` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Contributing
Please find contributing guide here [CONTRIBUTING.md](dev/CONTRIBUTING.md)

## Sponsors
> Built using Jetbrains Products
![Jetbrains](https://www.jetbrains.com/company/brand/img/jetbrains_logo.png)
